@@ -91,8 +91,9 @@ static void open_item_in_mauku(MaukuWidget* mauku_widget, const char* publisher,
 	DBusMessage* message;
 
 	message = dbus_message_new_method_call("com.innologies.mauku", "/com/innologies/mauku", "com.innologies.Mauku", "OpenItem");
+printf("%s %s %s\n", publisher, uri, uid);
 	dbus_message_append_args(message, DBUS_TYPE_STRING, &publisher, DBUS_TYPE_STRING, &uri, DBUS_TYPE_STRING, &uid, DBUS_TYPE_INVALID);	
-	dbus_connection_send(mauku_widget->priv->connection_system, message, NULL);
+	dbus_connection_send(mauku_widget->priv->connection_session, message, NULL);
 	dbus_message_unref(message);
 }
 
